@@ -19,6 +19,8 @@ export const CELL_TYPE_PREPROCESSOR = 'preprocessor';
 export const CELL_TYPE_POSTPROCESSOR = 'postprocessor';
 export const CELL_TYPE_REQUIREMENTS = 'requirements';
 export const CELL_TYPE_CVAT_INFO = 'cvat-info';
+export const CELL_TYPE_CVAT_PREPROCESSOR = 'cvat-preprocessor';
+export const CELL_TYPE_CVAT_POSTPROCESSOR = 'cvat-postprocessor';
 const CELL_TYPES: any[] = [
     {
         value: CELL_TYPE_NA,
@@ -55,6 +57,18 @@ const CELL_TYPES: any[] = [
         label: 'CVAT Info',
         helpText: 'The code in this cell will be parsed as cvat_info callback function.',
         chipColor: 'a32626'
+    },
+    {
+        value: CELL_TYPE_CVAT_PREPROCESSOR,
+        label: 'CVAT Pre processor',
+        helpText: 'The code in this cell will be parsed as CVAT preprocessor for the predict function of deployed model.',
+        chipColor: 'ee7a1a'
+    },
+    {
+        value: CELL_TYPE_CVAT_POSTPROCESSOR,
+        label: 'CVAT Post processor',
+        helpText: 'The code in this cell will be parsed as CVAT postprocessor for the predict function of deployed model.',
+        chipColor: '773d0d'
     }
 ];
 
@@ -105,6 +119,16 @@ def cvat_info(inputs: Dict = None) -> Dict:
         "description": ""
     }`
 
+const CVAT_PREPROCESSOR_DEF_REGEX = /\s*def\s+cvat_preprocess\s*\(\s*\S+\s*(:\s*\S+\s*)*\)\s*(->\s*\S+\s*)*:\s*/i
+const CVAT_PREPROCESSOR_DEFAULT_CODE_SNIPPET = `from typing import Dict
+def cvat_preprocess(input: Dict) -> Dict:
+    return input`
+
+const CVAT_POSTPROCESSOR_DEF_REGEX = /\s*def\s+cvat_postprocess\s*\(\s*\S+\s*(:\s*\S+\s*)*\)\s*(->\s*\S+\s*)*:\s*/i
+const CVAT_POSTPROCESSOR_DEFAULT_CODE_SNIPPET = `from typing import Dict
+def cvat_postprocess(input: Dict) -> Dict:
+    return []`
+
 const enum CellCodeErrors {
   VOID,
   FUNC_DEF_ERROR
@@ -167,6 +191,10 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
             return this.transformerStates.isRequirementsTagged;
         } else if(tag === CELL_TYPE_CVAT_INFO) {
             return this.transformerStates.isCVATInfoTagged;
+        } else if(tag === CELL_TYPE_CVAT_PREPROCESSOR) {
+            return this.transformerStates.isCVATPreprocessorTagged;
+        } else if(tag === CELL_TYPE_CVAT_POSTPROCESSOR) {
+            return this.transformerStates.isCVATPostprocessorTagged;
         }
         return false;
     }
@@ -180,6 +208,10 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
             this.transformerStates.isRequirementsTagged = tagged;
         } else if(tag === CELL_TYPE_CVAT_INFO) {
             this.transformerStates.isCVATInfoTagged = tagged;
+        } else if(tag === CELL_TYPE_CVAT_PREPROCESSOR) {
+            this.transformerStates.isCVATPreprocessorTagged = tagged;
+        } else if(tag === CELL_TYPE_CVAT_POSTPROCESSOR) {
+            this.transformerStates.isCVATPostprocessorTagged = tagged;
         }
     }
 
@@ -197,13 +229,19 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
 
     checkCellCodeDefinitionConfirmed = (notebook: Notebook, cellIndex: number, tag: string) => {
         console.log("checkCellCodeDefinitionConfirmed");
-        if(tag == CELL_TYPE_PREPROCESSOR || tag == CELL_TYPE_POSTPROCESSOR || tag == CELL_TYPE_CVAT_INFO) {
-            let regex = PREPROCESSOR_DEF_REGEX;
-            if(tag == CELL_TYPE_POSTPROCESSOR) {
-                regex = POSTPROCESSOR_DEF_REGEX;
-            } else if(tag == CELL_TYPE_CVAT_INFO) {
-                regex = CVAT_INFO_DEF_REGEX;
-            }
+        let regex = null;
+        if(tag == CELL_TYPE_PREPROCESSOR) {
+            regex = PREPROCESSOR_DEF_REGEX;
+        } else if(tag == CELL_TYPE_POSTPROCESSOR) {
+            regex = POSTPROCESSOR_DEF_REGEX;
+        } else if(tag == CELL_TYPE_CVAT_INFO) {
+            regex = CVAT_INFO_DEF_REGEX;
+        } else if(tag == CELL_TYPE_CVAT_PREPROCESSOR) {
+            regex = CVAT_PREPROCESSOR_DEF_REGEX;
+        } else if(tag == CELL_TYPE_CVAT_POSTPROCESSOR) {
+            regex = CVAT_POSTPROCESSOR_DEF_REGEX;
+        }
+        if(regex) {
             if(CellUtils.isCellVoid(notebook, cellIndex)) {
                 return {
                     confirmed: false,
@@ -233,7 +271,7 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
                 this.setState({ transformerTag: CELL_TYPE_NA });
             }
 
-            if(value == CELL_TYPE_PREPROCESSOR || value == CELL_TYPE_POSTPROCESSOR || value == CELL_TYPE_CVAT_INFO) {
+            if(value == CELL_TYPE_PREPROCESSOR || value == CELL_TYPE_POSTPROCESSOR || value == CELL_TYPE_CVAT_INFO || value == CELL_TYPE_CVAT_PREPROCESSOR || value == CELL_TYPE_CVAT_POSTPROCESSOR) {
                 let notebook: Notebook = this.props.notebookPanel.content;
                 let confirmedResult = this.checkCellCodeDefinitionConfirmed(notebook, notebook.activeCellIndex, value);
                 if(! confirmedResult.confirmed) {
@@ -242,6 +280,10 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
                         codeSnippet = POSTPROCESSOR_DEFAULT_CODE_SNIPPET;
                     } else if(value == CELL_TYPE_CVAT_INFO) {
                         codeSnippet = CVAT_INFO_DEFAULT_CODE_SNIPPET;
+                    } else if(value == CELL_TYPE_CVAT_PREPROCESSOR) {
+                        codeSnippet = CVAT_PREPROCESSOR_DEFAULT_CODE_SNIPPET;
+                    } else if(value == CELL_TYPE_CVAT_POSTPROCESSOR) {
+                        codeSnippet = CVAT_POSTPROCESSOR_DEFAULT_CODE_SNIPPET;
                     }
                     if(confirmedResult.error == CellCodeErrors.VOID) {
                         CellUtils.injectCodeAtIndex(notebook, notebook.activeCellIndex, codeSnippet);
@@ -271,7 +313,7 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
         console.log("saveCellTagInNotebookFile");
         let value = this.state.transformerTag;
 
-        if(value == CELL_TYPE_PREPROCESSOR || value == CELL_TYPE_POSTPROCESSOR || value == CELL_TYPE_CVAT_INFO) {
+            if(value == CELL_TYPE_PREPROCESSOR || value == CELL_TYPE_POSTPROCESSOR || value == CELL_TYPE_CVAT_INFO || value == CELL_TYPE_CVAT_PREPROCESSOR || value == CELL_TYPE_CVAT_POSTPROCESSOR) {
             let notebook: Notebook = this.props.notebookPanel.content;
             let confirmedResult = this.checkCellCodeDefinitionConfirmed(notebook, notebook.activeCellIndex, value);
             if(! confirmedResult.confirmed) {
@@ -292,6 +334,10 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
                         codeSnippet = POSTPROCESSOR_DEFAULT_CODE_SNIPPET;
                     } else if(value == CELL_TYPE_CVAT_INFO) {
                         codeSnippet = CVAT_INFO_DEFAULT_CODE_SNIPPET;
+                    } else if(value == CELL_TYPE_CVAT_PREPROCESSOR) {
+                        codeSnippet = CVAT_PREPROCESSOR_DEFAULT_CODE_SNIPPET;
+                    } else if(value == CELL_TYPE_CVAT_POSTPROCESSOR) {
+                        codeSnippet = CVAT_POSTPROCESSOR_DEFAULT_CODE_SNIPPET;
                     }
                     let dialogTitle = "Function %s is not well defined!".replace(/%s/i, value);
                     let dialogContent = "Please define function %s as follows:".replace(/%s/i, value);
@@ -307,7 +353,7 @@ export class CellMetadataEditor extends React.Component<IProps, IState> {
         }
 
         let isDuplicated = false;
-        if(value == CELL_TYPE_PREPROCESSOR || value == CELL_TYPE_POSTPROCESSOR || value == CELL_TYPE_REQUIREMENTS) {
+        if(value == CELL_TYPE_PREPROCESSOR || value == CELL_TYPE_POSTPROCESSOR || value == CELL_TYPE_CVAT_INFO || value == CELL_TYPE_CVAT_PREPROCESSOR || value == CELL_TYPE_CVAT_POSTPROCESSOR) {
             isDuplicated = TagsUtils.isTransformerTagExistedInOtherCells(
                 this.props.notebookPanel,
                 this.props.notebookPanel.content.activeCellIndex,
